'use strict';

const React = require('react');
const TopPanel = require('./components/panel-top');
const MiddlePanel = require('./components/panel-middle');
const BottomPanel = require('./components/panel-bottom');
const Background = require('./components/background');

class Nav extends React.PureComponent {
  constructor(props) {
    super(props);

    this.state = {
      isMobile: true,
      isOpen: false,
      activeSection: -1,
      breakpoint: 895
    };

    this.env = this.props.environment || 'com';

    this.toggle = this.toggle.bind(this);
    this.setActiveSection = this.setActiveSection.bind(this);
    this.onResize = this.onResize.bind(this);
  }

  componentDidMount() {
    this.setState({
      isMobile: window.innerWidth <= this.state.breakpoint
    });

    window.addEventListener('resize', () => {
      if (this.rafId) return;

      this.rafId = window.requestAnimationFrame(this.onResize);
    });
  }

  onResize() {
    const { isMobile, breakpoint } = this.state;
    const { innerWidth } = window;

    if (isMobile && innerWidth > breakpoint) {
      this.setState({ isMobile: false, isOpen: false, activeSection: -1 });
      document.body.classList.toggle('no-scroll', false);
    } else if (!isMobile && innerWidth <= breakpoint) {
      this.setState({ isMobile: true, activeSection: -1 });
    }

    this.rafId = undefined;
  }

  setActiveSection(activeSection) {
    this.setState({ activeSection });
  }

  toggle(isOpen) {
    console.log(isOpen);
    isOpen = typeof isOpen === 'boolean' ? isOpen : !this.state.isOpen;

    if (this.state.isMobile) {
      document.body.classList.toggle('no-scroll', isOpen);
    }

    this.setState({ isOpen });
  }

  render() {
    const active = this.state.activeSection;
    const mobile = this.state.isMobile;

    return React.createElement(
      'nav',
      {
        style: this.props.isTopNavHidden ? { top: '-45px' } : null,
        className: 'nav-panel flex flex--center-y flex--wrap' },
      React.createElement(TopPanel, {
        downloadUrl: this.props.downloadUrl,
        downloadJmpValue: this.props.downloadJmpValue,
        includeSearch: this.props.includeSearch,
        host: this.env === 'com' ? '' : 'https://www.mongodb.com',
        sections: this.props.topSections,
        searchUrl: this.props.searchUrl,
        contactUrl: this.props.contactUrl }),
      React.createElement(MiddlePanel, {
        activeSection: active,
        isMobile: mobile,
        logoUrl: this.props.logoUrl,
        tagline: this.props.tagline,
        logoLink: this.props.logoLink,
        sections: this.props.sections,
        toggle: this.toggle,
        setActiveSection: this.setActiveSection }),
      React.createElement(
        Background,
        {
          isMobile: mobile,
          setActiveSection: this.setActiveSection,
          isOpaque: this.state.isOpen || active !== -1 || this.props.isOpaque,
          isOpen: this.state.isOpen || active !== -1,
          isTopNavHidden: this.props.isTopNavHidden },
        React.createElement(BottomPanel, {
          isMobile: mobile,
          activeSection: active,
          midSections: this.props.sections,
          sections: this.props.subsections })
      )
    );
  }
}

module.exports = Nav;